import subprocess
import os

from flask import Flask, request
from PIL import Image, ImageDraw, ImageFont
import qrcode

#For USB-connected printer, e.g. QL-800:
#host = 'usb://0x04f9:0x209b'
#model = 'QL-800'

#For Wirless connected printer, e.g. QL-820NWB
#host = 'tcp://10.0.0.83'
#host = 'tcp://192.168.0.208'
model = 'QL-820NWB'

app = Flask(__name__)

@app.route('/print_label', methods=['POST'])
def print_label():
    try:
        # Parse JSON data from the HTTP POST request
        json_data = request.get_json()
        host = 'tcp://' + json_data['PrinterIP']
        qr_id = json_data['QR-ID']
        title = json_data['Title']
        size = json_data['Size']
        discount = json_data['Discount']
        price = json_data['Price']
        label_size = json_data['Labelsize']  # Get the label size from JSON data
        color_label = json_data['color']
        # Set label height, font size, and QR code size based on label size
        if label_size == 'standard':
            img_height = 220
            font_size = 36
            qr_size = (200, 200)
            qr_xpos = 400
            qr_ypos = 35
            text_ypos = 1
            label_text = f"{title}\n\n{size}\n{discount}\nPreis: {price}"
        elif label_size == 'small':
            img_height = 100
            font_size = 18
            qr_size = (100, 100)
            qr_xpos = 300
            qr_ypos = 0
            text_ypos = 8
            label_text = f"{title}\n{size}\n{discount}\nPreis: {price}"
        else:
            raise ValueError('Invalid label size')  # Raise error for invalid label size

        # Generate label image with QR code
        qr = qrcode.make(qr_id)
        qr = qr.resize(qr_size)
        img_width = 600
        img = Image.new('1', (img_width, img_height), 1)
        draw = ImageDraw.Draw(img)
        font = ImageFont.truetype('arial.ttf', font_size)
        draw.text((10, text_ypos), label_text, font=font)
        img.paste(qr, (qr_xpos, qr_ypos))
        print('1-trying to save image!')
        img.save('/home/pi/label.png')

        # Execute the brother_ql command to print the label
        # Execute the brother_ql command to print the label
        try:
            print('2-trying to run brother_ql!')
            with open("output.txt", "w") as out, open("error.txt", "w") as err:
                if color_label == "yes":
                	subprocess.run(['/home/pi/.local/bin/brother_ql', '-m', model, '-p', host, 'print', '-l', '62','--red', '-t', '50.0', 'label.png'],
                               	stdout=out, stderr=err)
                else:
                	subprocess.run(['/home/pi/.local/bin/brother_ql', '-m', model, '-p', host, 'print', '-l', '62', '-t', '50.0', 'label.png'],
                               	stdout=out, stderr=err)

            #subprocess.run(['/home/pi/.local/bin/brother_ql', '-m', model, host, 'print', '-l', '62', '-t', '50.0', 'label.png'])
            with open("error.txt", "r") as err:
                error = err.read()
            if error:
                print('Error:', error)
            else:
                print('3-Label printed successfully!')
        except subprocess.CalledProcessError as e:
            print('Error: {}'.format(e))
        finally:
            # Remove the label image file
            subprocess.run(['rm', '/home/pi/label.png'])
        return 'Label printed successfully'
    except Exception as e:
        return f'Error: {str(e)}'

if __name__ == '__main__':
    app.debug = True
    app.run(host='0.0.0.0', port=5000)  # Run the Flask app on all available network interfaces
